#ifndef SOCK_H
# define SOCK_H

void InitSrvr( void );
int OpenSrvr( WSCstring url, WSCstring port, int portN );
int CloseSrvr( int sock );

bool RecvSrvr(
	int sock, const WSCstring url, WSCstring *dst,
	long encoding );
bool RecvLine( int sock, WSCstring *dst, long encoding );

WSCstring ConvUrlToPath( WSCstring url );
WSCstring ConvUrlToHost( WSCstring url );

#endif /* SOCK_H */
